@@ -1,3 +1,3 @@
 library(testthat)
 library(dostats)
-test_package("dostats")
+test_check("dostats")
